@@ -1,7 +1,7 @@
 from pathlib import Path
 
-import pytest
 import numpy as np
+import pytest
 
 from webviz_subsurface._models.ensemble_set_model import EnsembleSetModel
 
@@ -12,18 +12,14 @@ def test_single_ensemble(testdata_folder):
     emodel = EnsembleSetModel(
         ensemble_paths={
             "iter-0": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-0"
-                )
+                Path(testdata_folder / "01_drogon_ahm" / "realization-*" / "iter-0")
             )
         }
     )
-    assert emodel.ens_folders == {
-        "iter-0": Path(testdata_folder) / "reek_history_match"
-    }
+    assert emodel.ens_folders == {"iter-0": Path(testdata_folder) / "01_drogon_ahm"}
     smry = emodel.get_or_load_smry_cached()
-    assert len(smry.columns) == 476
-    assert len(smry["DATE"].unique()) == 480
+    assert len(smry.columns) == 934
+    assert len(smry["DATE"].unique()) == 2369
     assert smry["ENSEMBLE"].unique() == ["iter-0"]
     assert smry["ENSEMBLE"].dtype == np.dtype("O")
     assert all(
@@ -35,7 +31,7 @@ def test_single_ensemble(testdata_folder):
     assert all(col in parameters.columns for col in ["ENSEMBLE", "REAL"])
     assert parameters["ENSEMBLE"].dtype == np.dtype("O")
     assert parameters["REAL"].dtype == np.dtype("int64")
-    assert len(parameters.columns) == 28
+    assert len(parameters.columns) == 56
 
 
 @pytest.mark.usefixtures("app")
@@ -44,33 +40,17 @@ def test_smry_load_multiple_ensembles(testdata_folder):
     emodel = EnsembleSetModel(
         ensemble_paths={
             "iter-0": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-0"
-                )
-            ),
-            "iter-1": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-1"
-                )
-            ),
-            "iter-2": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-2"
-                )
+                Path(testdata_folder / "01_drogon_ahm" / "realization-*" / "iter-0")
             ),
             "iter-3": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-3"
-                )
+                Path(testdata_folder / "01_drogon_ahm" / "realization-*" / "iter-3")
             ),
         }
     )
     smry = emodel.get_or_load_smry_cached()
-    assert len(smry.columns) == 476
-    assert len(smry["DATE"].unique()) == 1141
-    assert set(smry["ENSEMBLE"].unique()) == set(
-        ["iter-0", "iter-1", "iter-2", "iter-3"]
-    )
+    assert len(smry.columns) == 934
+    assert len(smry["DATE"].unique()) == 4167
+    assert set(smry["ENSEMBLE"].unique()) == set(["iter-0", "iter-3"])
     assert smry["ENSEMBLE"].dtype == np.dtype("O")
     # assert smry["DATE"].dtype == np.dtype("O") # Fails due to wrong input data?
     assert smry["REAL"].dtype == np.dtype("int64")
@@ -82,19 +62,19 @@ def test_smry_load_multiple_ensembles(testdata_folder):
     assert set(smeta.columns) == set(
         ["unit", "is_total", "is_rate", "is_historical", "keyword", "wgname", "get_num"]
     )
-    assert len(smeta) == 473
+    assert len(smeta) == 931
     assert "FOPT" in smeta.index
 
     parameters = emodel.load_parameters()
     assert all(col in parameters.columns for col in ["ENSEMBLE", "REAL"])
     assert parameters["ENSEMBLE"].dtype == np.dtype("O")
     assert parameters["REAL"].dtype == np.dtype("int64")
-    assert len(parameters.columns) == 28
+    assert len(parameters.columns) == 56
 
     dframe = emodel.load_csv(Path("share") / "results" / "tables" / "rft.csv")
     assert "ENSEMBLE" in dframe.columns
     assert dframe["ENSEMBLE"].dtype == np.dtype("O")
-    assert len(dframe["ENSEMBLE"].unique()) == 4
+    assert len(dframe["ENSEMBLE"].unique()) == 2
     assert len(dframe.columns) == 15
 
     with pytest.raises(KeyError) as exc:
@@ -110,32 +90,18 @@ def test_webvizstore(testdata_folder):
     emodel = EnsembleSetModel(
         ensemble_paths={
             "iter-0": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-0"
-                )
-            ),
-            "iter-1": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-1"
-                )
-            ),
-            "iter-2": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-2"
-                )
+                Path(testdata_folder / "01_drogon_ahm" / "realization-*" / "iter-0")
             ),
             "iter-3": str(
-                Path(
-                    testdata_folder / "reek_history_match" / "realization-*" / "iter-3"
-                )
+                Path(testdata_folder / "01_drogon_ahm" / "realization-*" / "iter-3")
             ),
         }
     )
     emodel.load_parameters()
-    assert len(emodel.webvizstore) == 4
+    assert len(emodel.webvizstore) == 2
     emodel.get_or_load_smry_cached()
-    assert len(emodel.webvizstore) == 8
+    assert len(emodel.webvizstore) == 4
     emodel.load_smry_meta()
-    assert len(emodel.webvizstore) == 12
+    assert len(emodel.webvizstore) == 6
     emodel.load_csv(Path("share") / "results" / "tables" / "rft.csv")
-    assert len(emodel.webvizstore) == 16
+    assert len(emodel.webvizstore) == 8
