@@ -10,7 +10,12 @@ from webviz_subsurface.plugins._property_statistics.models.property_statistics_m
 
 def get_data_df(testdata_folder: Path) -> pd.DataFrame:
 
-    return pd.read_csv(testdata_folder / "aggregated_data" / "property_statistics.csv")
+    return pd.read_csv(
+        testdata_folder
+        / "reek_test_data"
+        / "aggregated_data"
+        / "property_statistics.csv"
+    )
 
 
 def test_init(testdata_folder: Path) -> None:
