@@ -2,29 +2,31 @@ from typing import Dict, List
 
 import pandas as pd
 
-from webviz_subsurface.plugins._simulation_time_series.types import DeltaEnsemble
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._types import (
+    DeltaEnsemble,
+)
 
 # pylint: disable = line-too-long
-from webviz_subsurface.plugins._simulation_time_series.types.derived_delta_ensemble_vectors_accessor_impl import (
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.derived_ensemble_vectors_accessor_utils import (
+    create_derived_vectors_accessor_dict,
+)
+
+# pylint: disable = line-too-long
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.derived_vectors_accessor.derived_delta_ensemble_vectors_accessor_impl import (
     DerivedDeltaEnsembleVectorsAccessorImpl,
 )
 
 # pylint: disable = line-too-long
-from webviz_subsurface.plugins._simulation_time_series.types.derived_ensemble_vectors_accessor_impl import (
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.derived_vectors_accessor.derived_ensemble_vectors_accessor_impl import (
     DerivedEnsembleVectorsAccessorImpl,
 )
-from webviz_subsurface.plugins._simulation_time_series.types.derived_vectors_accessor import (
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.derived_vectors_accessor.derived_vectors_accessor import (
     DerivedVectorsAccessor,
 )
-from webviz_subsurface.plugins._simulation_time_series.types.provider_set import (
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.provider_set import (
     ProviderSet,
 )
 
-# pylint: disable = line-too-long
-from webviz_subsurface.plugins._simulation_time_series.utils.derived_ensemble_vectors_accessor_utils import (
-    create_derived_vectors_accessor_dict,
-)
-
 from ..mocks.derived_vectors_accessor_ensemble_summary_provider_mock import (
     EnsembleSummaryProviderMock,
 )
@@ -54,6 +56,7 @@ def test_create_derived_vectors_accessor_dict() -> None:
         expressions=[],
         delta_ensembles=delta_ensembles,
         resampling_frequency=None,
+        relative_date=None,
     )
 
     assert len(created_result) == len(ensembles)
