@@ -1,22 +1,24 @@
-import math
 import json
+import math
 import pathlib
 import warnings
-from typing import Optional, Union, List
-
+from typing import List, Optional, Tuple, Union
 
 _DATA_PATH = pathlib.Path(__file__).parent.absolute() / "abbreviation_data"
 
 SI_PREFIXES = json.loads((_DATA_PATH / "si_prefixes.json").read_text())
 
 
-def table_statistics_base() -> List[tuple]:
+def table_statistics_base() -> List[Tuple[str, dict]]:
     return [
         (
             i,
             {
                 "type": "numeric",
-                "format": {"locale": {"symbol": ["", ""]}, "specifier": "$.4s",},
+                "format": {
+                    "locale": {"symbol": ["", ""]},
+                    "specifier": "$.4s",
+                },
             },
         )
         if i != "Stddev"
@@ -24,7 +26,10 @@ def table_statistics_base() -> List[tuple]:
             i,
             {
                 "type": "numeric",
-                "format": {"locale": {"symbol": ["", ""]}, "specifier": "$.3s",},
+                "format": {
+                    "locale": {"symbol": ["", ""]},
+                    "specifier": "$.3s",
+                },
             },
         )
         for i in ["Mean", "Stddev", "Minimum", "P90", "P10", "Maximum"]
@@ -52,7 +57,7 @@ def si_prefixed(
      'M' (mega)) or an integer which is the base 10 exponent (e.g. 3 for kilo, -3 for milli).
     """
 
-    def number_formatter(number_base: float, si_prefix: str):
+    def number_formatter(number_base: float, si_prefix: str) -> str:
         return (
             f"{number_base:{number_format}} {si_prefix}{unit}"
             if spaced
@@ -86,7 +91,7 @@ def si_prefixed(
     (exp_div_3, log10_rem) = divmod(math.log10(math.fabs(number)), 3)
     # Take log 10 and then mod 3 as we have one prefix per 10^3, the divisor*3 is then the exponent
     return (
-        number_formatter(-(10 ** log10_rem), SI_PREFIXES[str(int(exp_div_3 * 3))])
+        number_formatter(-(10**log10_rem), SI_PREFIXES[str(int(exp_div_3 * 3))])
         if (number < 0)
-        else number_formatter(10 ** log10_rem, SI_PREFIXES[str(int(exp_div_3 * 3))])
+        else number_formatter(10**log10_rem, SI_PREFIXES[str(int(exp_div_3 * 3))])
     )
