@@ -36,21 +36,21 @@
 #
 ########################################
 
-from typing import Tuple, Callable, Union, Optional
+from typing import Callable, Optional, Tuple, Union
 
 import numpy as np
 from opm.io.ecl import EclFile
 
-from ..eclipse_unit import ConvertUnits, EclUnits, CreateUnitConverter, EclUnitEnum
+from ..eclipse_unit import ConvertUnits, CreateUnitConverter, EclUnitEnum, EclUnits
 from .pvt_common import (
-    surface_mass_density,
-    InitFileDefinitions,
     EclPhaseIndex,
-    PVTx,
-    PVDx,
-    PvxOBase,
     EclPropertyTableRawData,
     FluidImplementation,
+    InitFileDefinitions,
+    PVDx,
+    PVTx,
+    PvxOBase,
+    surface_mass_density,
 )
 
 
@@ -77,7 +77,6 @@ class WetGas(PvxOBase):
             ConvertUnits,
         ],
     ) -> None:
-        # pylint: disable=super-init-not-called
         """Initializes a WetGas object.
 
         Creates an interpolant for wet gas for the Eclipse data given
@@ -177,7 +176,6 @@ class DryGas(PvxOBase):
         surface_mass_density_gas: float,
         convert: ConvertUnits,
     ) -> None:
-        # pylint: disable=super-init-not-called
         """Initializes a DryGas object.
 
         Creates an interpolant for dry gas for the Eclipse data given
@@ -307,8 +305,8 @@ class Gas(FluidImplementation):
 
         if latex:
             return (
-                fr"${{{unit_system.reservoir_volume().symbol}}}"
-                fr"/{{{unit_system.surface_volume_gas().symbol}}}$"
+                rf"${{{unit_system.reservoir_volume().symbol}}}"
+                rf"/{{{unit_system.surface_volume_gas().symbol}}}$"
             )
         return (
             f"{unit_system.reservoir_volume().symbol}"
@@ -333,8 +331,8 @@ class Gas(FluidImplementation):
 
         if latex:
             return (
-                fr"${{{unit_system.surface_volume_liquid().symbol}}}/"
-                fr"{{{unit_system.surface_volume_gas().symbol}}}$"
+                rf"${{{unit_system.surface_volume_liquid().symbol}}}/"
+                rf"{{{unit_system.surface_volume_gas().symbol}}}$"
             )
         return (
             f"{unit_system.surface_volume_liquid().symbol}/"
