@@ -1,9 +1,9 @@
 from typing import List, Union
 
-import pandas as pd
 import numpy as np
+import pandas as pd
+
 
-# pylint: disable=dangerous-default-value
 def calc_from_cumulatives(
     data: pd.DataFrame,
     column_keys: Union[List[str], str],
@@ -103,7 +103,7 @@ def calc_from_cumulatives(
 def _verify_time_index(
     df: pd.DataFrame, time_index: str, time_index_input: str
 ) -> None:
-    freqs = {"D": "daily", "MS": "monthly", "YS": "yearly"}
+    freqs = {"D": "daily", "MS": "monthly", "AS-JAN": "yearly"}
     valid_time_indices = {
         "daily": ["daily", "monthly", "yearly"],
         "monthly": ["monthly", "yearly"],
