@@ -5,8 +5,8 @@
 ########################################
 
 import sys
-from typing import Dict, List, Any
 import warnings
+from typing import Any, Dict, List
 
 import numpy as np
 import pandas as pd
@@ -27,10 +27,10 @@ except ImportError:
 from webviz_config.common_cache import CACHE
 from webviz_config.webviz_store import webvizstore
 
-from .fmu_input import load_ensemble_set, load_csv
-from .eclipse_init_io.pvt_oil import Oil
 from .eclipse_init_io.pvt_gas import Gas
+from .eclipse_init_io.pvt_oil import Oil
 from .eclipse_init_io.pvt_water import Water
+from .fmu_input import load_csv, load_ensemble_set
 
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
@@ -101,9 +101,9 @@ def filter_pvt_data_frame(
         ens_merged_dataframe = data_frame.iloc[0:0]
         for _rno, realization_data_frame in ens_data_frame.groupby("REAL"):
             if ens_merged_dataframe.empty:
-                ens_merged_dataframe = ens_merged_dataframe.append(
-                    realization_data_frame
-                ).reset_index(drop=True)
+                ens_merged_dataframe = pd.concat(
+                    [ens_merged_dataframe, realization_data_frame], ignore_index=True
+                )
             else:
                 ens_merged_dataframe = (
                     pd.concat([ens_merged_dataframe, realization_data_frame])
@@ -220,7 +220,6 @@ def load_pvt_dataframe(
 
     def init_to_pvt_data_frame(kwargs: Any) -> pd.DataFrame:
         # pylint: disable-msg=too-many-locals
-        # pylint: disable=too-many-nested-blocks
         # pylint: disable=too-many-branches
         check_if_ecl2df_is_installed()
         ecl_init_file = EclFile(
