@@ -1,34 +1,30 @@
-from typing import List, Tuple, Union, Callable, Iterable
 import json
-from uuid import uuid4
 from pathlib import Path
+from typing import Callable, Iterable, List, Tuple, Union
+from uuid import uuid4
 
 import numpy as np
 import pandas as pd
-import dash
-from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State
-from dash_table import DataTable
-import dash_html_components as html
 import webviz_core_components as wcc
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from dash import Dash, Input, Output, State, callback_context, dash_table, html
+from dash.exceptions import PreventUpdate
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config.webviz_store import webvizstore
 from webviz_config.deprecation_decorators import deprecated_plugin
+from webviz_config.webviz_store import webvizstore
 
 from webviz_subsurface._components import TornadoWidget
-from .._datainput.inplace_volumes import extract_volumes
-from .._datainput.fmu_input import get_realizations, find_sens_type
-from .._abbreviations.volume_terminology import volume_description, volume_unit
+
 from .._abbreviations.number_formatting import table_statistics_base
+from .._abbreviations.volume_terminology import volume_description, volume_unit
+from .._datainput.fmu_input import find_sens_type, get_realizations
+from .._datainput.inplace_volumes import extract_volumes
 
 
 @deprecated_plugin(
     "Relevant functionality is implemented in the VolumetricAnalysis plugin."
 )
 class InplaceVolumesOneByOne(WebvizPluginABC):
-    # pylint: disable=too-many-instance-attributes
     """Visualizes inplace volumetrics related to a FMU ensemble with a design matrix.
 
 Input can be given either as an aggregated `csv` file for volumes and sensitivity information,
@@ -117,7 +113,7 @@ aggregated_data/parameters.csv)
     # pylint: disable=too-many-arguments
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         csvfile_vol: Path = None,
         csvfile_parameters: Path = None,
@@ -414,7 +410,7 @@ aggregated_data/parameters.csv)
                                     ),
                                     html.Div(
                                         style={"fontSize": "15px"},
-                                        children=DataTable(
+                                        children=dash_table.DataTable(
                                             id=self.uuid("table"),
                                             sort_action="native",
                                             filter_action="native",
@@ -440,7 +436,7 @@ aggregated_data/parameters.csv)
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             [
                 Output(self.tornadoplot.storage_id, "data"),
@@ -518,14 +514,14 @@ aggregated_data/parameters.csv)
             source: str,
             *filters: Union[str, List[str]],
         ) -> Tuple[Union[wcc.Graph, html.Div], str]:
-            if dash.callback_context.triggered is None:
+            if callback_context.triggered is None:
                 raise PreventUpdate
 
             tornado_click: Union[dict, None] = (
                 json.loads(tornado_click_data_str) if tornado_click_data_str else None
             )
 
-            ctx = dash.callback_context.triggered[0]["prop_id"].split(".")[0]
+            ctx = callback_context.triggered[0]["prop_id"].split(".")[0]
             if tornado_click:
                 if (
                     high_low_storage is not None
