@@ -1,23 +1,23 @@
-from typing import List, Callable, Tuple, Union, Optional, Dict
+from typing import Callable, Dict, List, Optional, Tuple, Union
 
 import numpy as np
 import pandas as pd
-import dash
+from dash import Dash, Input, Output, State, no_update
 from dash.exceptions import PreventUpdate
-from dash.dependencies import Input, Output, State
 from webviz_config.common_cache import CACHE
 
 from webviz_subsurface._models import ObservationModel
-from webviz_subsurface._providers import EnsembleTableProviderSet
+from webviz_subsurface._providers import EnsembleTableProvider
+
 from ..figures.plotly_line_plot import PlotlyLinePlot
 
 
 def build_figure(
-    app: dash.Dash,
+    app: Dash,
     get_uuid: Callable,
-    tableproviders: EnsembleTableProviderSet,
+    tableproviders: Dict[str, EnsembleTableProvider],
     observationmodel: Optional[ObservationModel],
-    parameterproviders: EnsembleTableProviderSet,
+    parameterproviders: Dict[str, EnsembleTableProvider],
     colors: Dict,
 ) -> None:
     @app.callback(
@@ -78,7 +78,7 @@ def build_figure(
             else []
         )
         if not ensemble_names:
-            return [], dash.no_update
+            return [], no_update
         ensemble_names = (
             [ensemble_names] if not isinstance(ensemble_names, list) else ensemble_names
         )
@@ -246,10 +246,10 @@ def calc_series_statistics(
     refaxis is used if another column than DATE should be used to groupby.
     """
     # Invert p10 and p90 due to oil industry convention.
-    def p10(x: List[float]) -> List[float]:
+    def p10(x: List[float]) -> np.floating:
         return np.nanpercentile(x, q=90)
 
-    def p90(x: List[float]) -> List[float]:
+    def p90(x: List[float]) -> np.floating:
         return np.nanpercentile(x, q=10)
 
     # Calculate statistics, ignoring NaNs.
@@ -274,7 +274,7 @@ def calc_series_statistics(
 
 @CACHE.memoize(timeout=CACHE.TIMEOUT)
 def get_table_data(
-    tableproviders: EnsembleTableProviderSet,
+    tableproviders: Dict[str, EnsembleTableProvider],
     ensemble_names: List,
     table_column_names: List,
     realization_filter: Dict[str, List],
@@ -285,7 +285,7 @@ def get_table_data(
         if not realization_filter.get(ens_name):
             dframe = pd.DataFrame(columns=["ENSEMBLE", "REAL"] + table_column_names)
         else:
-            provider = tableproviders.ensemble_provider(ens_name)
+            provider = tableproviders[ens_name]
             dframe = provider.get_column_data(
                 table_column_names, realizations=realization_filter.get(ens_name)
             )
