@@ -1,24 +1,36 @@
-from typing import Tuple, Union, Callable
+from typing import Callable, Tuple, Union
 
-import numpy as np
 import pandas as pd
-from dash.dependencies import Input, Output, State, ALL
+from dash import ALL, Dash, Input, Output, State, callback_context, no_update
+from dash._callback import NoUpdate
 from dash.exceptions import PreventUpdate
-import dash
 
+from webviz_subsurface._figures import BarChart, ScatterPlot, TimeSeriesFigure
 from webviz_subsurface._models import SurfaceLeafletModel
-from ..utils.colors import find_intermediate_color_rgba
-from ..figures.correlation_figure import CorrelationFigure
+from webviz_subsurface._utils.dataframe_utils import (
+    correlate_response_with_dataframe,
+    merge_dataframes_on_realization,
+)
+
+# pylint: disable=line-too-long
+from webviz_subsurface.plugins._simulation_time_series._views._subplot_view._utils.datetime_utils import (
+    from_str,
+)
+
+from ..models import (
+    PropertyStatisticsModel,
+    ProviderTimeSeriesDataModel,
+    SimulationTimeSeriesModel,
+)
 from ..utils.surface import surface_from_zone_prop
-from ..models import PropertyStatisticsModel, SimulationTimeSeriesModel
 
 
 def property_response_controller(
     get_uuid: Callable,
     surface_table: pd.DataFrame,
     property_model: PropertyStatisticsModel,
-    timeseries_model: SimulationTimeSeriesModel,
-    app: dash.Dash,
+    timeseries_model: Union[SimulationTimeSeriesModel, ProviderTimeSeriesDataModel],
+    app: Dash,
 ) -> None:
     @app.callback(
         Output({"id": get_uuid("surface-view"), "tab": "response"}, "layers"),
@@ -45,7 +57,7 @@ def property_response_controller(
                 )
             except ValueError:  # Surface does not exist
                 return (
-                    dash.no_update,
+                    no_update,
                     f"No surface found for {stype.capitalize()} for {prop}, {zone}",
                 )
             surface_layer = SurfaceLeafletModel(surface, name="surface").layer
@@ -62,15 +74,14 @@ def property_response_controller(
         Input(get_uuid("property-response-correlated-filter"), "value"),
         Input({"id": get_uuid("ensemble-selector"), "tab": "response"}, "value"),
     )
-    # pylint: disable=protected-access
     def _update_correlation_figure(
         label: str, ensemble: str
     ) -> Tuple[
-        Union[float, dash.dash._NoUpdate],
-        Union[float, dash.dash._NoUpdate],
-        Union[float, dash.dash._NoUpdate],
+        Union[float, NoUpdate],
+        Union[float, NoUpdate],
+        Union[float, NoUpdate],
         list,
-        Union[dict, dash.dash._NoUpdate],
+        Union[dict, NoUpdate],
         bool,
     ]:
         if label is not None:
@@ -88,19 +99,20 @@ def property_response_controller(
             )
 
         return (
-            dash.no_update,
-            dash.no_update,
-            dash.no_update,
+            no_update,
+            no_update,
+            no_update,
             [None, None],
-            dash.no_update,
+            no_update,
             True,
         )
 
     @app.callback(
         Output(get_uuid("property-response-vector-graph"), "figure"),
         Output(get_uuid("property-response-correlation-graph"), "figure"),
+        Output(get_uuid("property-response-scatter-graph"), "figure"),
         Input({"id": get_uuid("ensemble-selector"), "tab": "response"}, "value"),
-        Input(get_uuid("property-response-vector-select"), "value"),
+        Input(get_uuid("property-response-vector-select"), "selectedNodes"),
         Input(get_uuid("property-response-vector-graph"), "clickData"),
         Input(get_uuid("property-response-correlation-graph"), "clickData"),
         Input(
@@ -125,14 +137,18 @@ def property_response_controller(
         corr_filter: list,
         figure: dict,
         label: str,
-    ) -> Tuple[dict, dict]:
+    ) -> Tuple[dict, dict, dict]:
+
         if (
-            dash.callback_context.triggered is None
-            or dash.callback_context.triggered[0]["prop_id"] == "."
+            callback_context.triggered is None
+            or callback_context.triggered[0]["prop_id"] == "."
             or vector is None
+            or not vector
+            or not all(filt for filt in selectors)
         ):
             raise PreventUpdate
-        ctx = dash.callback_context.triggered[0]["prop_id"].split(".")[0]
+
+        vector = vector[0]
 
         # Filter realizations if correlation filter is active
         real_filter = (
@@ -141,20 +157,6 @@ def property_response_controller(
             else None
         )
 
-        # Make timeseries graph
-        if any(
-            substr in ctx
-            for substr in [
-                get_uuid("property-response-vector-select"),
-                get_uuid("ensemble-selector"),
-                get_uuid("property-response-correlated-slider"),
-            ]
-        ):
-
-            figure = update_timeseries_graph(
-                timeseries_model, ensemble, vector, real_filter
-            )
-
         # Get clicked data or last available date initially
         date = (
             timeseries_clickdata.get("points", [{}])[0].get(
@@ -163,33 +165,40 @@ def property_response_controller(
             if timeseries_clickdata
             else timeseries_model.get_last_date(ensemble)
         )
-
-        # Draw clicked date as a black line
-        ymin = min([min(trace["y"]) for trace in figure["data"]])
-        ymax = max([max(trace["y"]) for trace in figure["data"]])
-        figure["layout"]["shapes"] = [
-            {"type": "line", "x0": date, "x1": date, "y0": ymin, "y1": ymax}
-        ]
+        date = from_str(date) if isinstance(date, str) else date
 
         # Get dataframe with vector and REAL
-        vector_df = timeseries_model.get_ensemble_vector_for_date(
-            ensemble=ensemble, vector=vector, date=date
+        vector_df = timeseries_model.get_vector_df(
+            ensemble=ensemble, vectors=[vector], realizations=real_filter
         )
-        vector_df["REAL"] = vector_df["REAL"].astype(int)
+        if date not in vector_df["DATE"].values or vector not in vector_df:
+            return {}, {}, {}
 
         # Get dataframe with properties per label and REAL
         prop_df = property_model.get_ensemble_properties(ensemble, selectors)
-        prop_df["REAL"] = prop_df["REAL"].astype(int)
         prop_df = (
             prop_df[prop_df["REAL"].isin(real_filter)]
             if real_filter is not None
             else prop_df
         )
 
+        merged_df = merge_dataframes_on_realization(
+            dframe1=vector_df[vector_df["DATE"] == date], dframe2=prop_df
+        )
         # Correlate properties against vector
-        corrseries = correlate(vector_df, prop_df, response=vector)
+        corrseries = correlate_response_with_dataframe(
+            merged_df,
+            response=vector,
+            corrwith=[col for col in prop_df if col != "REAL"],
+        )
+        # Handle missing
+        if corrseries.empty:
+            return {}, {}, {}
+
         # Make correlation figure
-        correlation_figure = CorrelationFigure(corrseries, n_rows=20, title="")
+        correlation_figure = BarChart(
+            corrseries, n_rows=15, title=f"Correlations with {vector}", orientation="h"
+        )
 
         # Get clicked correlation bar or largest bar initially
         selected_corr = (
@@ -199,72 +208,34 @@ def property_response_controller(
         )
 
         # Update bar colors
-        correlation_figure.set_bar_colors(selected_corr)
+        correlation_figure.color_bars(selected_corr, color="#007079", opacity=0.5)
+        prop_df_norm = property_model.get_real_and_value_df(
+            ensemble, series=selected_corr, normalize=True
+        )
+        figure = TimeSeriesFigure(
+            dframe=merge_dataframes_on_realization(vector_df, prop_df_norm),
+            visualization="realizations",
+            vector=vector,
+            ensemble=ensemble,
+            dateline=date,
+            historical_vector_df=timeseries_model.get_historical_vector_df(
+                vector, ensemble
+            ),
+            color_col=selected_corr,
+            line_shape_fallback=timeseries_model.line_shape_fallback,
+        ).figure
 
-        # Order realizations sorted on value of property
-        real_order = (
-            property_model.get_real_order(ensemble, series=selected_corr)
-            if selected_corr is not None
-            else None
+        scatter_fig = (
+            ScatterPlot(
+                merged_df,
+                response=vector,
+                param=selected_corr,
+                color="#007079",
+                title=f"{vector} vs {selected_corr}",
+                plot_trendline=True,
+            ).figure
+            if selected_corr in merged_df
+            else {}
         )
 
-        # Color timeseries lines from value of property
-        if real_order is not None:
-            mean = real_order["Avg"].mean()
-            low_reals = real_order[real_order["Avg"] <= mean]["REAL"].astype(str).values
-            high_reals = real_order[real_order["Avg"] > mean]["REAL"].astype(str).values
-            for trace_no, trace in enumerate(figure.get("data", [])):
-                if trace["name"] == ensemble:
-                    figure["data"][trace_no]["marker"]["color"] = set_real_color(
-                        str(trace["customdata"]), low_reals, high_reals
-                    )
-            figure["layout"]["title"] = f"Colored by {selected_corr}"
-
-        return figure, correlation_figure.figure
-
-
-def set_real_color(real_no: str, low_reals: list, high_reals: list) -> str:
-
-    if real_no in low_reals:
-        index = int(list(low_reals).index(real_no))
-        intermed = index / len(low_reals)
-        return find_intermediate_color_rgba(
-            "rgba(255,0,0, 100, .1)", "rgba(220,220,220, 0.1)", intermed
-        )
-    if real_no in high_reals:
-        index = int(list(high_reals).index(real_no))
-        intermed = index / len(high_reals)
-        return find_intermediate_color_rgba(
-            "rgba(220,220,220, 0.1)", "rgba(50,205,50, 1)", intermed
-        )
-
-    return "rgba(220,220,220, 0.2)"
-
-
-def update_timeseries_graph(
-    timeseries_model: SimulationTimeSeriesModel,
-    ensemble: str,
-    vector: str,
-    real_filter: pd.Series = None,
-) -> dict:
-
-    return {
-        "data": timeseries_model.add_realization_traces(
-            ensemble=ensemble, vector=vector, real_filter=real_filter
-        ),
-        "layout": dict(
-            margin={"r": 40, "l": 40, "t": 40, "b": 40},
-        ),
-    }
-
-
-def correlate(vectordf: pd.DataFrame, propdf: pd.DataFrame, response: str) -> pd.Series:
-    """Returns the correlation matrix for a dataframe"""
-    df = pd.merge(propdf, vectordf, on=["REAL"])
-    df = df[df.columns[df.nunique() > 1]]
-    if response not in df.columns:
-        df[response] = np.nan
-    series = df[response]
-    df = df.drop(columns=[response, "REAL"])
-    corrdf = df.corrwith(series)
-    return corrdf.reindex(corrdf.abs().sort_values().index)
+        return figure, correlation_figure.figure, scatter_fig
