@@ -3,7 +3,6 @@ from typing import Any, List, Tuple
 import numpy as np
 import pandas as pd
 import plotly.graph_objects as go
-from dash.dash_table.Format import Format
 from webviz_config import WebvizConfigTheme
 
 from webviz_subsurface._figures import create_figure
@@ -32,6 +31,7 @@ class PropertyStatisticsModel:
 
     def __init__(self, dataframe: pd.DataFrame, theme: WebvizConfigTheme) -> None:
         self._dataframe = dataframe
+        self._dataframe["REAL"] = self._dataframe["REAL"].astype(int)
         self._prepare_and_validate_data()
         self._dataframe["label"] = self._dataframe.agg(
             lambda x: " | ".join(
@@ -95,6 +95,10 @@ class PropertyStatisticsModel:
     def properties(self) -> List[str]:
         return list(self.dataframe["PROPERTY"].unique())
 
+    @property
+    def zones(self) -> List[str]:
+        return list(self.dataframe["ZONE"].unique())
+
     @property
     def sources(self) -> List[str]:
         return list(self.dataframe["SOURCE"].unique())
@@ -175,6 +179,8 @@ class PropertyStatisticsModel:
         if selector_values is not None:
             df = self.filter_dataframe(df, self.selectors, selector_values)
         df = df[["REAL", statistic, "label"]]
+        if df.empty:
+            return df
         return (
             df.pivot_table(columns=["label"], values=statistic, index="REAL")
             .rename_axis(None, axis=1)
@@ -200,6 +206,9 @@ class PropertyStatisticsModel:
             lambda x: " | ".join([f"{x[sel]}" for sel in self.selectors]), axis=1
         )
 
+        # Drop non-numerical columns before aggregations
+        df = df.drop(columns=["SOURCE", "PROPERTY"] + self.selectors)
+
         df = df[df["ENSEMBLE"].isin([ensemble, delta_ensemble])]
         df = df.pivot_table(columns=["ENSEMBLE"], index="label").reset_index()
 
@@ -292,7 +301,7 @@ class PropertyStatisticsModel:
                 "id": col,
                 "name": [col.split("|")[0], col.split("|")[1]],
                 "type": "numeric",
-                "format": Format(precision=3),
+                "format": {"specifier": ".3~r"},
             }
             for col in df.columns
         ]
@@ -309,6 +318,8 @@ class PropertyStatisticsModel:
         if selector_values is not None:
             df = self.filter_dataframe(df, self.selectors, selector_values)
 
+        # Drop non-numerical columns before aggregations
+        df = df.drop(columns=["SOURCE", "PROPERTY"] + self.selectors)
         df = df[df["ENSEMBLE"].isin(ensembles)]
         df = df.pivot_table(columns=["ENSEMBLE"], index="label").reset_index()
         return self.make_table(df)
@@ -348,3 +359,25 @@ class PropertyStatisticsModel:
         fig = fig.to_dict()
         fig["layout"] = self.theme.create_themed_layout(fig["layout"])
         return fig
+
+    def get_real_and_value_df(
+        self,
+        ensemble: str,
+        series: str,
+        normalize: bool = False,
+        statistic: str = "Avg",
+    ) -> pd.DataFrame:
+        """
+        Return dataframe with label and values for selected label for an ensemble.
+        A column with normalized values can be added.
+        """
+        df = self.dataframe[self.dataframe["ENSEMBLE"] == ensemble]
+        df = df[df["label"] == series]
+        if normalize:
+            df["VALUE_NORM"] = (df[statistic] - df[statistic].min()) / (
+                df[statistic].max() - df[statistic].min()
+            )
+
+        df.rename(columns={statistic: "VALUE"}, inplace=True)
+
+        return df[["label", "REAL", "VALUE", "VALUE_NORM"]].reset_index(drop=True)
