@@ -1,16 +1,13 @@
-from typing import Union, Optional, List, Tuple, Callable
 import json
+from typing import Callable, List, Optional, Tuple, Union
 
-import pandas as pd
 import numpy as np
-import dash
-import dash_html_components as html
+import pandas as pd
 import webviz_core_components as wcc
-from dash.dependencies import Input, Output
-from webviz_config.webviz_store import webvizstore
+from dash import Dash, Input, Output, html
+from webviz_config import WebvizPluginABC, WebvizSettings
 from webviz_config.common_cache import CACHE
-from webviz_config import WebvizPluginABC
-from webviz_config import WebvizSettings
+from webviz_config.webviz_store import webvizstore
 
 from .._datainput.fmu_input import load_ensemble_set, load_parameters
 
@@ -63,7 +60,7 @@ blob/master/reek_history_match/realization-0/iter-0/status.json).
 
     def __init__(
         self,
-        app: dash.Dash,
+        app: Dash,
         webviz_settings: WebvizSettings,
         ensembles: list,
         filter_shorter: Union[int, float] = 10,
@@ -277,7 +274,7 @@ blob/master/reek_history_match/realization-0/iter-0/status.json).
             ],
         )
 
-    def set_callbacks(self, app: dash.Dash) -> None:
+    def set_callbacks(self, app: Dash) -> None:
         @app.callback(
             Output(self.uuid("fig"), "figure"),
             [
@@ -496,7 +493,7 @@ def render_parcoord(
         "type": "parcoords",
     }
     if color_col == "STATUS_BOOL":
-        data["line"].update(  # pylint: disable=expression-not-assigned
+        data["line"].update(
             {
                 "cmin": -0.5,
                 "cmax": 1.5,
@@ -511,7 +508,7 @@ def render_parcoord(
             },
         )
     else:
-        data["line"].update(  # pylint: disable=expression-not-assigned
+        data["line"].update(
             {
                 "colorbar": {
                     "title": "Running time",
