@@ -1,6 +1,6 @@
+from .dialog_controller import open_dialogs
 from .intersection_controller import update_intersection
 from .intersection_source_controller import update_intersection_source
 from .map_controller import update_maps
-from .modal_controller import open_modals
 from .realization_filter_controller import update_realizations
 from .uncertainty_table_controller import update_uncertainty_table
