@@ -1,8 +1,8 @@
-from typing import Callable, Optional, List, Dict
-import dash_html_components as html
+from typing import Callable, Dict, List, Optional
+
 import webviz_core_components as wcc
+from dash import html
 from webviz_subsurface_components import LeafletMap
-from .uncertainty_table import uncertainty_table_layout
 
 
 def intersection_and_map_layout(get_uuid: Callable) -> html.Div:
@@ -65,16 +65,6 @@ def intersection_and_map_layout(get_uuid: Callable) -> html.Div:
                             ),
                         ],
                     ),
-                    wcc.Frame(
-                        id={
-                            "id": get_uuid("uncertainty-table"),
-                            "element": "wrapper",
-                        },
-                        style={"height": "40vh", "display": "none"},
-                        children=uncertainty_table_layout(
-                            uuid=get_uuid("uncertainty-table"),
-                        ),
-                    ),
                 ],
             ),
         ],
